pyramid_oas3
============

[Pyramid](https://trypyramid.com/) Webアプリケーションに対して、
[OpenAPI](https://www.openapis.org/) [3.0](https://github.com/OAI/OpenAPI-Specification/blob/master/versions/3.0.0.md)を利用した、
リクエストの検証・パースを実施するライブラリです。

[pyramid_swagger](https://github.com/striglia/pyramid_swagger)のOpenAPI 3.0対応版の様な位置づけです。
